#ifndef GPXI3052_HEADER
#define GPXI3052_HEADER



/*-------------------------------------------------------------------------*/
/* Defines                                                                 */
/*-------------------------------------------------------------------------*/
#define K_DLL_VERSION		251   // Version 2.51

#define K_DEV_MAX			12
#define PORT_COUNT			4
#define MONITOR_ITEM_SIZE	20    // Byteanzahl siehe typdef in Firmware

// XILINX command structure
#define K_HEADER_XILINX_INSTRUCTION_GLOBAL      0    // start byte
#define K_HEADER_XILINX_CARD_NUMBER             1    // device (1 ... K_DEV_MAX)
#define K_HEADER_XILINX_PORT_NUMBER             2    // not used
#define K_HEADER_XILINX_INSTRUCTION             3    // command
#define K_HEADER_XILINX_FIRST_DATA              4    
#define K_HEADER_XILINX_LENGTH                  4     

#define K_READ                      0
#define K_WRITE                     1

#define K_HEADER_XILINX_START_BYTE  0x48

// XILINX commands
#define K_XILINX_CMD_PO_RESET       0x10
#define K_XILINX_CMD_EXT_CLOCK      0x11
#define K_XILINX_CMD_REG_WRITE      0x12

/*-------------------------------------------------------------------------*/
/* Typedefs                                                                */
/*-------------------------------------------------------------------------*/
typedef struct
	{
	unsigned long Version;
	unsigned long DevCount;
	unsigned long SW_XILINX[K_DEV_MAX];
	unsigned long BusIndexes[K_DEV_MAX];
	unsigned long DevIndexes[K_DEV_MAX];
	unsigned long GeoAddress[K_DEV_MAX];
	unsigned long SerialNumber[K_DEV_MAX];
	unsigned long Revision[K_DEV_MAX];
	} GPxi3052_StructDriverInfo;

typedef struct
	{
	unsigned long Mode;
	unsigned long Register;
	unsigned long Value;
	} GPxi3080_StructXilinxReadWrite;

/*-------------------------------------------------------------------------*/
/* Errorcodes                                                              */
/*-------------------------------------------------------------------------*/
// 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  Sev:      is the severity code
//               00 - Success
//               01 - Informational
//               10 - Warning
//               11 - Error
//  C:        is the Customer code flag
//  R:        is a reserved bit
//  Facility: is the facility code
//  Code:     is the facility's status code

// error codes (all sources)
#define K_NO_ERROR                               0x00000000
// error driver
#define K_UNKNOWN_IOCTRL                         0xE0000001
#define K_NOTSUPPORTED_DEVICE                    0xE0000002
#define K_XILINX_DOWNLOADERROR                   0xE0000003
#define K_XILINX_WRITE_DATA_HEADER               0xE0000004

#define K_STATUS_DPRAM_BUFFER_BOUNDS_EXCEEDED    0xE000000A
#define K_STATUS_DPRAM_NOT_ENOUGH_BUFFER         0xE000000B
#define K_STATUS_DPRAM_SEMAPHORE_TIMEOUT         0xE000000C
#define K_STATUS_DPRAM_LIST_ITEM_NOT_EMPTY       0xE000000D
#define K_STATUS_NOT_ENOUGH_USER_INPUT_BUFFER    0xE000000E
#define K_STATUS_NOT_ENOUGH_USER_OUTPUT_BUFFER   0xE000000F
#define K_STATUS_INVALID_DATA_LENGTH             0xE0000010
#define K_STATUS_EEPROM_NO_ACK                   0xE0000011
#define K_STATUS_EEPROM_NO_START_CONDITION       0xE0000012
#define K_STATUS_EEPROM_UNDEFINED                0xE0000013

#define K_UNDEFINED_ERROR                        0xE00000F0
// error library
#define K_INVALID_HANDLE                         0xE0000100
#define K_ERR_DLINVALIDID                        0xE0000101
#define K_ERR_DLINVALIDVERSION                   0xE0000102
#define K_ERR_DLSIZE                             0xE0000103
#define K_ERR_DLFILE                             0xE0000104
#define K_NO_CARD_PRESENT                        0xE0000105



/******************************************
 * Goepel function
 *****************************************/
#ifdef __EXPORT_DLL	// creating DLL
	#define INTEGRATION_MODE	__declspec(dllexport)
#else				// using in customer application
	#define INTEGRATION_MODE	__declspec(dllimport)
#endif

#ifdef __cplusplus
	extern "C" {
#endif

INTEGRATION_MODE int GPxi3052_GetDriverInfo(GPxi3052_StructDriverInfo*);
INTEGRATION_MODE int GPxi3052_DLL_Version(unsigned long*);
INTEGRATION_MODE int GPxi3052_XilinxDownload(unsigned long, char*);
INTEGRATION_MODE int GPxi3052_DpramWriteInstruction(unsigned char *data,
                                                    unsigned long  length);
INTEGRATION_MODE int GPxi3052_DpramReadResponse(unsigned long  card,
                                                unsigned long  port,
                                                unsigned char *data,
                                                unsigned long *length);
INTEGRATION_MODE int GPxi3052_DpramReadMonitor(unsigned long  card,
                                               unsigned long  port,
                                               unsigned char *data,
                                               unsigned long *length);
INTEGRATION_MODE int GPxi3052_ResetPort(unsigned long card,
                                        unsigned long port);
INTEGRATION_MODE int GPxi3052_XilinxWriteData(unsigned char *data,
                                              unsigned long *length);

#ifdef __cplusplus
	}
#endif

#endif